==> vod-common-1.0.0-sources.jar: com/valor/vod/common/web/request/LoginCodeArgs.java <==
package com.valor.vod.common.web.request;

import com.google.common.base.Strings;

/**
 * @ClassName: LoginCodeDo
 * @Auther: admin
 * @Date: 1/4/2019
 * @Version 1.0
 * @Description:
 */
public class LoginCodeArgs extends BaseRequestArgs {


    private String token;
    private String sessionId;
    private String did;
    private Long vendorId;

    public LoginCodeArgs() {
    }

    public String getToken() {
        return token;
    }

    public void setToken(String token) {
        this.token = token;
    }

    public String getSessionId() {
        return sessionId;
    }

    public void setSessionId(String sessionId) {
        this.sessionId = sessionId;
    }

    public String getDid() {
        return did;
    }

    public void setDid(String did) {
        this.did = did;
    }

    public Long getVendorId() {
        return vendorId;
    }

    public void setVendorId(Long vendorId) {
        this.vendorId = vendorId;
    }


    @Override
    public boolean isArgsValid() {


        if (isNullOrEmpty((Object) super.getAccountId())) {
            setVerifyMsg("accountId", "Can NOT be null");
            argsValid = false;
        }

        if (isNullOrEmpty((Object) super.getAccountType())) {
            setVerifyMsg("accountType", "Can NOT be null");
            argsValid = false;
        }

        if (isNullOrEmpty((Object) vendorId)) {
            setVerifyMsg("vendorId", "Can NOT be null");
            argsValid = false;
        }


        return super.isArgsValid();
    }

    private boolean isNullOrEmpty(Object value) {
        if (value instanceof String) {
            return Strings.isNullOrEmpty((String) value);
        } else {
            return (value == null);
        }
    }
}

==> vod-common-1.0.2-sources.jar: com/valor/vod/common/web/request/LoginCodeArgs.java <==
package com.valor.vod.common.web.request;

import com.google.common.base.Strings;

/**
 * @ClassName: LoginCodeDo @Auther: admin @Date: 1/4/2019 @Version 1.0 @Description:
 */
public class LoginCodeArgs extends BaseRequestArgs {

    private String token;
    private String sessionId;
    private String did;
    private Long vendorId;

    public LoginCodeArgs() {}

    public String getToken() {
        return token;
    }

    public void setToken(String token) {
        this.token = token;
    }

    public String getSessionId() {
        return sessionId;
    }

    public void setSessionId(String sessionId) {
        this.sessionId = sessionId;
    }

    public String getDid() {
        return did;
    }

    public void setDid(String did) {
        this.did = did;
    }

    public Long getVendorId() {
        return vendorId;
    }

    public void setVendorId(Long vendorId) {
        this.vendorId = vendorId;
    }

    @Override
    public boolean isArgsValid() {

        if (isNullOrEmpty((Object) super.getAccountId())) {
            setVerifyMsg("accountId", "Can NOT be null");
            argsValid = false;
        }

        if (isNullOrEmpty((Object) super.getAccountType())) {
            setVerifyMsg("accountType", "Can NOT be null");
            argsValid = false;
        }

        if (isNullOrEmpty((Object) vendorId)) {
            setVerifyMsg("vendorId", "Can NOT be null");
            argsValid = false;
        }

        return super.isArgsValid();
    }

    private boolean isNullOrEmpty(Object value) {
        if (value instanceof String) {
            return Strings.isNullOrEmpty((String) value);
        } else {
            return (value == null);
        }
    }
}
